@@ -9,12 +9,6 @@
 #ifndef __FEMONCFG_H
 #define __FEMONCFG_H
 
-#ifdef FEMON_DEBUG
-#define Dprintf(x...) printf(x);
-#else
-#define Dprintf(x...) ;
-#endif
-
 enum eFemonModes
 {
   eFemonModeBasic,
@@ -30,6 +24,7 @@ public:
   cFemonConfig(void);
   int hidemenu;
   int displaymode;
+  int skin;
   int theme;
   int position;
   int redlimit;
@@ -45,17 +40,28 @@ public:
 
 extern cFemonConfig femonConfig;
 
+enum eFemonSkins
+{
+  eFemonSkinClassic,
+  eFemonSkinElchi,
+  eFemonSkinMaxNumber
+};
+
 enum eFemonThemes
 {
   eFemonThemeClassic,
   eFemonThemeElchi,
   eFemonThemeDeepBlue,
   eFemonThemeMoronimo,
+  eFemonThemeEnigma,
+  eFemonThemeEgalsTry,
+  eFemonThemeDuotone,
   eFemonThemeMaxNumber
 };
 
 struct cFemonTheme
 {
+  int bpp;
   int clrBackground;
   int clrTitleBackground;
   int clrTitleText;
