@@ -15,7 +15,7 @@ const tI18nPhrase Phrases[] = {
     "Visualizza le informazioni sul segnale DVB", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Affiche les informations du signal DVB", // Franais
     "", // Norsk
     "Signaalimittari (OSD)", // suomi
     "", // Polski
@@ -36,7 +36,7 @@ const tI18nPhrase Phrases[] = {
     "Informazioni sul segnale", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Signal DVB", // Franais
     "", // Norsk
     "Signaalimittari", // suomi
     "", // Polski
@@ -57,7 +57,7 @@ const tI18nPhrase Phrases[] = {
     "Posizione", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Position", // Franais
     "", // Norsk
     "Sijainti", // suomi
     "", // Polski
@@ -78,7 +78,7 @@ const tI18nPhrase Phrases[] = {
     "Altezza", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Hauteur", // Franais
     "", // Norsk
     "Korkeus", // suomi
     "", // Polski
@@ -99,7 +99,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Dplacement horizontal", // Franais
     "", // Norsk
     "Vaakakeskitys", // suomi
     "", // Polski
@@ -120,11 +120,11 @@ const tI18nPhrase Phrases[] = {
     "Modo di visualizzazione standard", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais 
+    "Affichage par dfaut", // Franais
     "", // Norsk
     "Oletusnytttila", // suomi
-    "", // Polski   
-    "", // Espaol  
+    "", // Polski
+    "", // Espaol
     "", //  (Greek)
     "", // Svenska
     "", // Romaneste
@@ -141,11 +141,11 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais 
+    "basique", // Franais
     "", // Norsk
     "perus", // suomi
-    "", // Polski   
-    "", // Espaol  
+    "", // Polski
+    "", // Espaol
     "", //  (Greek)
     "", // Svenska
     "", // Romaneste
@@ -162,11 +162,11 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais 
+    "transpondeur", // Franais
     "", // Norsk
     "transponderi", // suomi
-    "", // Polski   
-    "", // Espaol  
+    "", // Polski
+    "", // Espaol
     "", //  (Greek)
     "", // Svenska
     "", // Romaneste
@@ -183,11 +183,11 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais 
+    "flux", // Franais
     "", // Norsk
     "lhete", // suomi
-    "", // Polski   
-    "", // Espaol  
+    "", // Polski
+    "", // Espaol
     "", //  (Greek)
     "", // Svenska
     "", // Romaneste
@@ -198,17 +198,38 @@ const tI18nPhrase Phrases[] = {
     "voog", // Eesti
     "", // Dansk
   },
+  { "Skin", // English
+    "Oberflche", // Deutsch
+    "", // Slovenski
+    "", // Italiano
+    "", // Nederlands
+    "", // Portugus
+    "Skin", // Franais
+    "", // Norsk
+    "Ulkoasu", // suomi
+    "", // Polski
+    "", // Espaol  
+    "", //  (Greek)
+    "", // Svenska
+    "", // Romaneste
+    "", // Magyar
+    "", // Catal 
+    "", //  (Russian)
+    "", // Hrvatski (Croatian)
+    "Kest", // Eesti
+    "", // Dansk 
+  },
   { "Theme", // English
     "Thema", // Deutsch
     "", // Slovenski
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais 
+    "Thme", // Franais
     "", // Norsk
     "Teema", // suomi
-    "", // Polski   
-    "", // Espaol  
+    "", // Polski
+    "", // Espaol
     "", //  (Greek)
     "", // Svenska
     "", // Romaneste
@@ -225,16 +246,16 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais 
+    "Classique", // Franais
     "", // Norsk
     "Klassinen", // suomi
-    "", // Polski   
-    "", // Espaol  
+    "", // Polski
+    "", // Espaol
     "", //  (Greek)
     "", // Svenska
     "", // Romaneste
-    "", // Magyar  
-    "", // Catal  
+    "", // Magyar
+    "", // Catal
     "", //  (Russian)
     "", // Hrvatski (Croatian)
     "Klassikaline", // Eesti
@@ -246,16 +267,16 @@ const tI18nPhrase Phrases[] = {
     "Elchi", // Italiano
     "Elchi", // Nederlands
     "Elchi", // Portugus
-    "Elchi", // Franais 
+    "Elchi", // Franais
     "Elchi", // Norsk
     "Elchi", // suomi
-    "Elchi", // Polski   
-    "Elchi", // Espaol  
+    "Elchi", // Polski
+    "Elchi", // Espaol
     "Elchi", //  (Greek)
     "Elchi", // Svenska
     "Elchi", // Romaneste
-    "Elchi", // Magyar  
-    "Elchi", // Catal  
+    "Elchi", // Magyar
+    "Elchi", // Catal
     "Elchi", //  (Russian)
     "Elchi", // Hrvatski (Croatian)
     "Elchi", // Eesti
@@ -267,16 +288,16 @@ const tI18nPhrase Phrases[] = {
     "DeepBlue", // Italiano
     "DeepBlue", // Nederlands
     "DeepBlue", // Portugus
-    "DeepBlue", // Franais 
+    "DeepBlue", // Franais
     "DeepBlue", // Norsk
     "DeepBlue", // suomi
-    "DeepBlue", // Polski   
-    "DeepBlue", // Espaol  
+    "DeepBlue", // Polski
+    "DeepBlue", // Espaol
     "DeepBlue", //  (Greek)
     "DeepBlue", // Svenska
     "DeepBlue", // Romaneste
-    "DeepBlue", // Magyar  
-    "DeepBlue", // Catal  
+    "DeepBlue", // Magyar
+    "DeepBlue", // Catal
     "DeepBlue", //  (Russian)
     "DeepBlue", // Hrvatski (Croatian)
     "DeepBlue", // Eesti
@@ -288,28 +309,91 @@ const tI18nPhrase Phrases[] = {
     "Moronimo", // Italiano
     "Moronimo", // Nederlands
     "Moronimo", // Portugus
-    "Moronimo", // Franais 
+    "Moronimo", // Franais
     "Moronimo", // Norsk
     "Moronimo", // suomi
-    "Moronimo", // Polski   
-    "Moronimo", // Espaol  
+    "Moronimo", // Polski
+    "Moronimo", // Espaol
     "Moronimo", //  (Greek)
     "Moronimo", // Svenska
     "Moronimo", // Romaneste
-    "Moronimo", // Magyar  
-    "Moronimo", // Catal  
+    "Moronimo", // Magyar
+    "Moronimo", // Catal
     "Moronimo", //  (Russian)
     "Moronimo", // Hrvatski (Croatian)
     "Moronimo", // Eesti
     "Moronimo", // Dansk
   },
+  { "Enigma", // English
+    "Enigma", // Deutsch
+    "Enigma", // Slovenski
+    "Enigma", // Italiano
+    "Enigma", // Nederlands
+    "Enigma", // Portugus
+    "Enigma", // Franais
+    "Enigma", // Norsk
+    "Enigma", // suomi
+    "Enigma", // Polski
+    "Enigma", // Espaol
+    "Enigma", //  (Greek)
+    "Enigma", // Svenska
+    "Enigma", // Romaneste
+    "Enigma", // Magyar
+    "Enigma", // Catal
+    "Enigma", //  (Russian)
+    "Enigma", // Hrvatski (Croatian)
+    "Enigma", // Eesti
+    "Enigma", // Dansk
+  },
+  { "EgalsTry", // English
+    "EgalsTry", // Deutsch
+    "EgalsTry", // Slovenski
+    "EgalsTry", // Italiano
+    "EgalsTry", // Nederlands
+    "EgalsTry", // Portugus
+    "EgalsTry", // Franais
+    "EgalsTry", // Norsk
+    "EgalsTry", // suomi
+    "EgalsTry", // Polski
+    "EgalsTry", // Espaol
+    "EgalsTry", //  (Greek)
+    "EgalsTry", // Svenska
+    "EgalsTry", // Romaneste
+    "EgalsTry", // Magyar
+    "EgalsTry", // Catal
+    "EgalsTry", //  (Russian)
+    "EgalsTry", // Hrvatski (Croatian)
+    "EgalsTry", // Eesti
+    "EgalsTry", // Dansk
+  },
+  { "Duotone", // English
+    "Duotone", // Deutsch
+    "Duotone", // Slovenski
+    "Duotone", // Italiano
+    "Duotone", // Nederlands
+    "Duotone", // Portugus
+    "Duotone", // Franais
+    "Duotone", // Norsk
+    "Duotone", // suomi
+    "Duotone", // Polski
+    "Duotone", // Espaol
+    "Duotone", //  (Greek)
+    "Duotone", // Svenska
+    "Duotone", // Romaneste
+    "Duotone", // Magyar
+    "Duotone", // Catal
+    "Duotone", //  (Russian)
+    "Duotone", // Hrvatski (Croatian)
+    "Duotone", // Eesti
+    "Duotone", // Dansk
+  },
   { "Hide main menu entry", // English
     "Hauptmeneintrag verstecken", // Deutsch
     "", // Slovenski
     "Nascondi voce men", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Masquer dans le menu principal", // Franais
     "", // Norsk
     "Piilota valinta pvalikosta", // suomi
     "", // Polski
@@ -330,7 +414,7 @@ const tI18nPhrase Phrases[] = {
     "Intervallo di aggiornamento [0.1s]", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Intervalle de mise  jour (0,1s)", // Franais
     "", // Norsk
     "Nytn pivitysvli [0.1s]", // suomi
     "", // Polski
@@ -351,7 +435,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Analyser le flux", // Franais
     "", // Norsk
     "Lhetteen analysointi", // suomi
     "", // Polski
@@ -372,7 +456,7 @@ const tI18nPhrase Phrases[] = {
     "Intervallo di calcolo [0.1s]", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Intervalle de calcul (0,1s)", // Franais
     "", // Norsk
     "Laskennan pivitysvli [0.1s]", // suomi
     "", // Polski
@@ -393,7 +477,7 @@ const tI18nPhrase Phrases[] = {
     "Limite rosso [%]", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Limite du rouge (%)", // Franais
     "", // Norsk
     "Punaisen taso [%]", // suomi
     "", // Polski
@@ -414,7 +498,7 @@ const tI18nPhrase Phrases[] = {
     "Limite verde [%]", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Limite du vert (%)", // Franais
     "", // Norsk
     "Vihren taso [%]", // suomi
     "", // Polski
@@ -435,10 +519,10 @@ const tI18nPhrase Phrases[] = {
     "Informazioni transponder", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Information transpondeur", // Franais
     "", // Norsk   
     "Transponderin tiedot", // suomi
-    "", // Polski   
+    "", // Polski
     "", // Espaol
     "", //  (Greek)
     "", // Svenska
@@ -456,7 +540,7 @@ const tI18nPhrase Phrases[] = {
     "Scheda satellitare", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Carte Satellite", // Franais
     "", // Norsk
     "Satelliittikortti", // suomi
     "", // Polski
@@ -477,7 +561,7 @@ const tI18nPhrase Phrases[] = {
     "Scheda via cavo", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Carte Cble", // Franais
     "", // Norsk
     "Kaapelikortti", // suomi
     "", // Polski
@@ -498,7 +582,7 @@ const tI18nPhrase Phrases[] = {
     "Scheda terrestre", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Carte TNT", // Franais
     "", // Norsk
     "Terrestiaalikortti", // suomi
     "", // Polski
@@ -519,7 +603,7 @@ const tI18nPhrase Phrases[] = {
     "Registra su syslog", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Enregistrer les infos dans syslog", // Franais
     "", // Norsk
     "Kirjaa systeemilokiin", // suomi
     "", // Polski
@@ -561,7 +645,7 @@ const tI18nPhrase Phrases[] = {
     "Video", // Italiano
     "Video", // Nederlands
     "Video", // Portugus
-    "Video", // Franais
+    "Vido", // Franais
     "Video", // Norsk
     "Kuva", // suomi
     "Video", // Polski
@@ -603,7 +687,7 @@ const tI18nPhrase Phrases[] = {
     "None", // Italiano
     "None", // Nederlands
     "None", // Portugus
-    "None", // Franais
+    "Aucun", // Franais
     "None", // Norsk
     "ei", // suomi
     "None", // Polski
@@ -624,7 +708,7 @@ const tI18nPhrase Phrases[] = {
     "Off", // Italiano
     "Off", // Nederlands
     "Off", // Portugus
-    "Off", // Franais
+    "Non", // Franais
     "Off", // Norsk
     "poissa", // suomi
     "Off", // Polski
@@ -645,7 +729,7 @@ const tI18nPhrase Phrases[] = {
     "On", // Italiano
     "On", // Nederlands
     "On", // Portugus
-    "On", // Franais
+    "Oui", // Franais
     "On", // Norsk
     "pll", // suomi
     "On", // Polski
@@ -729,7 +813,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Information flux", // Franais
     "", // Norsk
     "Lhetteen tiedot", // suomi
     "", // Polski
@@ -750,7 +834,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "MPEG Layer", // Franais
     "", // Norsk
     "MPEG-taso", // suomi
     "", // Polski
@@ -771,7 +855,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Flux vido", // Franais
     "", // Norsk
     "Kuvaraita", // suomi
     "", // Polski
@@ -792,7 +876,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Bitrate", // Franais
     "", // Norsk
     "Bittinopeus", // suomi
     "", // Polski
@@ -813,7 +897,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Rafrachissement", // Franais
     "", // Norsk
     "Ruudunpivitysnopeus", // suomi
     "", // Polski
@@ -855,7 +939,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Proportions d'image", // Franais
     "", // Norsk
     "Kuvasuhde", // suomi
     "", // Polski
@@ -876,7 +960,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "rserv", // Franais
     "", // Norsk
     "varattu", // suomi
     "", // Polski
@@ -897,10 +981,10 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "libre", // Franais
     "", // Norsk
     "vapaa", // suomi
-    "", // Polski   
+    "", // Polski
     "", // Espaol
     "", //  (Greek)
     "", // Svenska
@@ -918,7 +1002,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Standard vido", // Franais
     "", // Norsk
     "Kuvaformaatti", // suomi
     "", // Polski
@@ -981,7 +1065,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "inconnu", // Franais
     "", // Norsk
     "tuntematon", // suomi
     "", // Polski
@@ -1002,7 +1086,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Rsolution", // Franais
     "", // Norsk
     "Resoluutio", // suomi
     "", // Polski
@@ -1023,7 +1107,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Flux audio", // Franais
     "", // Norsk
     "niraita", // suomi
     "", // Polski
@@ -1044,7 +1128,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Frquence d'chantillonage", // Franais
     "", // Norsk
     "Nytteenottotaajuus", // suomi
     "", // Polski
@@ -1068,7 +1152,7 @@ const tI18nPhrase Phrases[] = {
     "kHz", // Franais
     "kHz", // Norsk
     "kHz", // suomi
-    "kHz", // Polski   
+    "kHz", // Polski
     "kHz", // Espaol
     "kHz", //  (Greek)
     "kHz", // Svenska
@@ -1185,6 +1269,27 @@ const tI18nPhrase Phrases[] = {
     "Rid", // Eesti
     "Rid", // Dansk
   },
+  { "Coderate", // English
+    "Coderate", // Deutsch
+    "Coderate", // Slovenski
+    "Coderate", // Italiano
+    "Coderate", // Nederlands
+    "Coderate", // Portugus
+    "Coderate", // Franais
+    "Coderate", // Norsk
+    "Suojaustaso", // suomi
+    "Coderate", // Polski
+    "Coderate", // Espaol
+    "Coderate", //  (Greek)
+    "Coderate", // Svenska
+    "Coderate", // Romaneste
+    "Coderate", // Magyar
+    "Coderate", // Catal
+    "Coderate", //  (Russian)
+    "Coderate", // Hrvatski (Croatian)
+    "Coderate", // Eesti
+    "Coderate", // Dansk
+  },
   { "dB", // English
     "dB", // Deutsch
     "dB", // Slovenski
@@ -1194,7 +1299,7 @@ const tI18nPhrase Phrases[] = {
     "dB", // Franais
     "dB", // Norsk
     "dB", // suomi
-    "dB", // Polski   
+    "dB", // Polski
     "dB", // Espaol
     "dB", //  (Greek)
     "dB", // Svenska
@@ -1212,7 +1317,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "non indiqu", // Franais
     "", // Norsk
     "ei ilmaistu", // suomi
     "", // Polski
@@ -1254,7 +1359,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Flux AC-3", // Franais
     "", // Norsk
     "AC-3-niraita", // suomi
     "", // Polski
@@ -1275,7 +1380,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Taille de paquet", // Franais
     "", // Norsk
     "Kehyksen koko", // suomi
     "", // Polski
@@ -1296,7 +1401,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Mode bitstream", // Franais
     "", // Norsk
     "Lhetteen tyyppi", // suomi
     "", // Polski
@@ -1317,7 +1422,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Mode de codage audio", // Franais
     "", // Norsk
     "nikoodaus", // suomi
     "", // Polski
@@ -1338,7 +1443,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Niveau sonore milieu", // Franais
     "", // Norsk
     "Keskikanavan taso", // suomi
     "", // Polski
@@ -1359,7 +1464,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Niveau sonore surround", // Franais
     "", // Norsk
     "Tehostekanavien taso", // suomi
     "", // Polski
@@ -1380,7 +1485,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Mode Dolby Surround", // Franais
     "", // Norsk
     "Dolby Surround -tehoste", // suomi
     "", // Polski
@@ -1401,7 +1506,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Effets de basses", // Franais
     "", // Norsk
     "LFE-kanava", // suomi
     "", // Polski
@@ -1422,7 +1527,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Normalisation des dialogues", // Franais
     "", // Norsk
     "Dialogin normalisointi", // suomi
     "", // Polski
@@ -1443,7 +1548,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Principal (CM)", // Franais
     "", // Norsk
     "Pasiallinen (CM)", // suomi
     "", // Polski
@@ -1464,7 +1569,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Musique et effets (ME)", // Franais
     "", // Norsk
     "Musiikki ja tehosteet (ME)", // suomi
     "", // Polski
@@ -1485,7 +1590,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Malvoyants (VI)", // Franais
     "", // Norsk
     "Nkrajoitteinen (VI)", // suomi
     "", // Polski
@@ -1506,7 +1611,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Malentendants (HI)", // Franais
     "", // Norsk
     "Kuulorajoitteinen (HI)", // suomi
     "", // Polski
@@ -1527,7 +1632,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Dialogue (D)", // Franais
     "", // Norsk
     "Vuoropuhelu (D)", // suomi
     "", // Polski
@@ -1548,7 +1653,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Commentaires (C)", // Franais
     "", // Norsk
     "Kommentointi (C)", // suomi
     "", // Polski
@@ -1569,7 +1674,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Urgence (E)", // Franais
     "", // Norsk
     "Httiedote (E)", // suomi
     "", // Polski
@@ -1590,7 +1695,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Voix off (VO)", // Franais
     "", // Norsk
     "Plle puhuttu (VO)", // suomi
     "", // Polski
@@ -1611,7 +1716,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Karaoke", // Franais
     "", // Norsk
     "Karaoke", // suomi
     "", // Polski
@@ -1632,7 +1737,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Can. 1", // Franais
     "", // Norsk
     "kan. 1", // suomi
     "", // Polski
@@ -1653,7 +1758,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Can. 2", // Franais
     "", // Norsk
     "kan. 2", // suomi
     "", // Polski
@@ -1674,7 +1779,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Centre", // Franais
     "", // Norsk
     "K", // suomi
     "", // Polski
@@ -1695,7 +1800,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Gauche", // Franais
     "", // Norsk
     "V", // suomi
     "", // Polski
@@ -1716,7 +1821,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Droite", // Franais
     "", // Norsk
     "O", // suomi
     "", // Polski
@@ -1737,7 +1842,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Surround", // Franais
     "", // Norsk
     "T", // suomi
     "", // Polski
@@ -1758,7 +1863,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Surround gauche", // Franais
     "", // Norsk
     "TV", // suomi
     "", // Polski
@@ -1779,7 +1884,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Surround droit", // Franais
     "", // Norsk
     "TO", // suomi
     "", // Polski
@@ -1800,7 +1905,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Systme CA", // Franais
     "", // Norsk
     "Nyt salausjrjestelm", // suomi
     "", // Polski
@@ -1821,7 +1926,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Fixe", // Franais
     "", // Norsk
     "kiinte", // suomi
     "", // Polski
@@ -1836,13 +1941,34 @@ const tI18nPhrase Phrases[] = {
     "Fikseeritud", // Eesti
     "", // Dansk
   },
+  { "Analog", // English
+    "", // Deutsch
+    "", // Slovenski
+    "", // Italiano
+    "", // Nederlands
+    "", // Portugus
+    "Analogique", // Franais
+    "", // Norsk
+    "analoginen", // suomi
+    "", // Polski
+    "", // Espaol
+    "", //  (Greek)
+    "", // Svenska
+    "", // Romaneste
+    "", // Magyar
+    "", // Catal
+    "", //  (Russian)
+    "", // Hrvatski (Croatian)
+    "", // Eesti
+    "", // Dansk
+  },
   { "Free to Air", // English
     "Free to Air", // Deutsch
     "", // Slovenski
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Free To Air", // Franais
     "", // Norsk
     "salaamaton", // suomi
     "", // Polski
@@ -1863,7 +1989,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "SECA/Mediaguard", // Franais
     "", // Norsk
     "SECA/Mediaguard", // suomi
     "", // Polski
@@ -1884,7 +2010,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Viaccess", // Franais
     "", // Norsk
     "Viaccess", // suomi
     "", // Polski
@@ -1905,7 +2031,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Irdeto", // Franais
     "", // Norsk
     "Irdeto", // suomi
     "", // Polski
@@ -1926,7 +2052,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "NDS/Videoguard", // Franais
     "", // Norsk
     "NDS/Videoguard", // suomi
     "", // Polski
@@ -1947,7 +2073,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "Conax", // Franais
     "", // Norsk
     "Conax", // suomi
     "", // Polski
@@ -1968,7 +2094,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "CryptoWorks", // Franais
     "", // Norsk
     "CryptoWorks", // suomi
     "", // Polski
@@ -1989,7 +2115,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "PowerVu", // Franais
     "", // Norsk
     "PowerVu", // suomi
     "", // Polski
@@ -2010,7 +2136,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "BetaCrypt", // Franais
     "", // Norsk
     "BetaCrypt", // suomi
     "", // Polski
@@ -2031,7 +2157,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "NagraVision", // Franais
     "", // Norsk
     "NagraVision", // suomi
     "", // Polski
@@ -2052,7 +2178,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italiano
     "", // Nederlands
     "", // Portugus
-    "", // Franais
+    "SkyCrypt", // Franais
     "", // Norsk   
     "SkyCrypt", // suomi
     "", // Polski
