@@ -10,6 +10,7 @@
 #include "femoncfg.h"
 #include "femoni18n.h"
 #include "femonreceiver.h"
+#include "femontools.h"
 #include "femonosd.h"
 
 #include "symbols/device.xpm"
@@ -37,7 +38,6 @@
 #include "symbols/viterbi.xpm"
 #include "symbols/sync.xpm"
 
-#define FRONTEND_DEVICE           "/dev/dvb/adapter%d/frontend%d"
 #define CHANNELINPUT_TIMEOUT      1000
 
 #define OSDHEIGHT                 femonConfig.osdheight   // in pixels
@@ -47,6 +47,7 @@
 #define OSDSTATUSHEIGHT           (OSDROWHEIGHT * 6)      // in pixels (6 rows)
 #define OSDSPACING                5
 #define OSDCORNERING              10
+#define IS_OSDCORNERING           (femonConfig.skin == eFemonSkinElchi)
 
 #define OSDINFOWIN_Y(offset)      (femonConfig.position ? (OSDHEIGHT - OSDINFOHEIGHT + offset) : offset)
 #define OSDINFOWIN_X(col)         ((col == 4) ? 455 : (col == 3) ? 305 : (col == 2) ? 155 : 15)
@@ -80,14 +81,25 @@ cBitmap cFemonOsd::bmCarrier(carrier_xpm);
 cBitmap cFemonOsd::bmViterbi(viterbi_xpm);
 cBitmap cFemonOsd::bmSync(sync_xpm);
 
-cFemonOsd::cFemonOsd(void)
+cFemonOsd *cFemonOsd::pInstance = NULL;
+
+cFemonOsd *cFemonOsd::Instance(bool create)
+{
+  Dprintf("%s()\n", __PRETTY_FUNCTION__);
+  if (pInstance == NULL && create)
+  {
+     pInstance = new cFemonOsd();
+  }
+  return (pInstance);
+}
+
+cFemonOsd::cFemonOsd()
 :cOsdObject(true), cThread("femon osd")
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
   m_Osd = NULL;
   m_Receiver = NULL;
   m_Frontend = -1;
-  m_Active = false;
   m_Number = 0;
   m_OldNumber = 0;
   m_Signal = 0;
@@ -110,14 +122,13 @@ cFemonOsd::cFemonOsd(void)
 cFemonOsd::~cFemonOsd(void)
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
-  if (m_Active) {
-     m_Active = false;
+  if (Running())
      Cancel(3);
-     }
   if (m_Receiver)
      delete m_Receiver;
   if (m_Osd)
      delete m_Osd;
+  pInstance = NULL;
 }
 
 void cFemonOsd::DrawStatusWindow(void)
@@ -138,8 +149,10 @@ void cFemonOsd::DrawStatusWindow(void)
      snprintf(buf, sizeof(buf), "%d%s %s", m_Number ? m_Number : channel->Number(), m_Number ? "-" : "", channel->ShortName(true));
      m_Osd->DrawRectangle(0, OSDSTATUSWIN_Y(offset), OSDWIDTH, OSDSTATUSWIN_Y(offset+OSDROWHEIGHT-1), femonTheme[femonConfig.theme].clrTitleBackground);
      m_Osd->DrawText(OSDSTATUSWIN_X(1), OSDSTATUSWIN_Y(offset), buf, femonTheme[femonConfig.theme].clrTitleText, femonTheme[femonConfig.theme].clrTitleBackground, m_Font);
-     m_Osd->DrawEllipse(0, OSDSTATUSWIN_Y(0), OSDCORNERING, OSDSTATUSWIN_Y(OSDCORNERING), clrTransparent, -2);
-     m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDSTATUSWIN_Y(0), OSDWIDTH, OSDSTATUSWIN_Y(OSDCORNERING), clrTransparent, -1);
+     if (IS_OSDCORNERING) {
+        m_Osd->DrawEllipse(0, OSDSTATUSWIN_Y(0), OSDCORNERING, OSDSTATUSWIN_Y(OSDCORNERING), clrTransparent, -2);
+        m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDSTATUSWIN_Y(0), OSDWIDTH, OSDSTATUSWIN_Y(OSDCORNERING), clrTransparent, -1);
+        }
      if (m_Receiver) {
         value = cDevice::ActualDevice()->CardIndex();
         if (value == 1) {
@@ -345,8 +358,10 @@ void cFemonOsd::DrawStatusWindow(void)
      m_Osd->DrawBitmap(OSDSTATUSWIN_XSYMBOL(3, x), OSDSTATUSWIN_Y(offset + y), bmCarrier, (m_FrontendStatus & FE_HAS_CARRIER) ? femonTheme[femonConfig.theme].clrActiveText : femonTheme[femonConfig.theme].clrRed, femonTheme[femonConfig.theme].clrBackground);
      m_Osd->DrawBitmap(OSDSTATUSWIN_XSYMBOL(4, x), OSDSTATUSWIN_Y(offset + y), bmViterbi, (m_FrontendStatus & FE_HAS_VITERBI) ? femonTheme[femonConfig.theme].clrActiveText : femonTheme[femonConfig.theme].clrRed, femonTheme[femonConfig.theme].clrBackground);
      m_Osd->DrawBitmap(OSDSTATUSWIN_XSYMBOL(5, x), OSDSTATUSWIN_Y(offset + y), bmSync, (m_FrontendStatus & FE_HAS_SYNC) ? femonTheme[femonConfig.theme].clrActiveText : femonTheme[femonConfig.theme].clrRed, femonTheme[femonConfig.theme].clrBackground);
-     m_Osd->DrawEllipse(0, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT-OSDCORNERING), OSDCORNERING, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT), clrTransparent, -3);
-     m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDSTATUSWIN_Y(OSDSTATUSHEIGHT-OSDCORNERING), OSDWIDTH, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT), clrTransparent, -4);
+     if (IS_OSDCORNERING) {
+        m_Osd->DrawEllipse(0, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT-OSDCORNERING), OSDCORNERING, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT), clrTransparent, -3);
+        m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDSTATUSWIN_Y(OSDSTATUSHEIGHT-OSDCORNERING), OSDWIDTH, OSDSTATUSWIN_Y(OSDSTATUSHEIGHT), clrTransparent, -4);
+        }
      m_Osd->Flush();
      }
 }
@@ -367,8 +382,10 @@ void cFemonOsd::DrawInfoWindow(void)
         m_Osd->DrawRectangle(0, OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), femonTheme[femonConfig.theme].clrBackground);
         m_Osd->DrawRectangle(0, OSDINFOWIN_Y(offset), OSDWIDTH, OSDINFOWIN_Y(offset+OSDROWHEIGHT-1), femonTheme[femonConfig.theme].clrTitleBackground);
         m_Osd->DrawText( OSDINFOWIN_X(1), OSDINFOWIN_Y(offset), tr("Transponder Information"), femonTheme[femonConfig.theme].clrTitleText, femonTheme[femonConfig.theme].clrTitleBackground, m_Font);
-        m_Osd->DrawEllipse(0, OSDINFOWIN_Y(0), OSDCORNERING, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -2);
-        m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -1);
+        if (IS_OSDCORNERING) {
+           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(0), OSDCORNERING, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -2);
+           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -1);
+           }
         offset += OSDROWHEIGHT;
         m_Osd->DrawText(OSDINFOWIN_X(1), OSDINFOWIN_Y(offset), tr("Vpid"), femonTheme[femonConfig.theme].clrInactiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
         snprintf(buf, sizeof(buf), "%d", channel->Vpid());
@@ -405,7 +422,10 @@ void cFemonOsd::DrawInfoWindow(void)
                   break;
              case 0x0001 ... 0x00FF:
                   /* Standardized systems */
-                  snprintf(buf, sizeof(buf), "%s", tr("Fixed"));
+                  if ((value == 0x00A0) || (value == 0x00A1))
+                     snprintf(buf, sizeof(buf), "%s", tr("Analog"));
+                  else
+                     snprintf(buf, sizeof(buf), "%s", tr("Fixed"));
                   break;
              case 0x0100 ... 0x01FF:
                   /* Canal Plus */
@@ -613,29 +633,29 @@ void cFemonOsd::DrawInfoWindow(void)
                else if (value == INVERSION_ON)    snprintf(buf, sizeof(buf), tr("On"));
                else            /*INVERSION_AUTO*/ snprintf(buf, sizeof(buf), tr("Auto"));
                m_Osd->DrawText(OSDINFOWIN_X(2), OSDINFOWIN_Y(offset), buf, femonTheme[femonConfig.theme].clrActiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
-               m_Osd->DrawText(OSDINFOWIN_X(3), OSDINFOWIN_Y(offset), tr("CoderateH"), femonTheme[femonConfig.theme].clrInactiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
+               m_Osd->DrawText(OSDINFOWIN_X(3), OSDINFOWIN_Y(offset), tr("Coderate"), femonTheme[femonConfig.theme].clrInactiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
                value = channel->CoderateH();
-               if      (value == FEC_NONE)  snprintf(buf, sizeof(buf), tr("None"));
-               else if (value == FEC_1_2)   snprintf(buf, sizeof(buf), "1/2");
-               else if (value == FEC_2_3)   snprintf(buf, sizeof(buf), "2/3");
-               else if (value == FEC_3_4)   snprintf(buf, sizeof(buf), "3/4");
-               else if (value == FEC_4_5)   snprintf(buf, sizeof(buf), "4/5");
-               else if (value == FEC_5_6)   snprintf(buf, sizeof(buf), "5/6");
-               else if (value == FEC_6_7)   snprintf(buf, sizeof(buf), "6/7");
-               else if (value == FEC_7_8)   snprintf(buf, sizeof(buf), "7/8");
-               else if (value == FEC_8_9)   snprintf(buf, sizeof(buf), "8/9");
-               else            /*FEC_AUTO*/ snprintf(buf, sizeof(buf), tr("Auto"));
+               if      (value == FEC_NONE)  snprintf(buf, sizeof(buf), "%s (H)", tr("None"));
+               else if (value == FEC_1_2)   snprintf(buf, sizeof(buf), "1/2 (H)");
+               else if (value == FEC_2_3)   snprintf(buf, sizeof(buf), "2/3 (H)");
+               else if (value == FEC_3_4)   snprintf(buf, sizeof(buf), "3/4 (H)");
+               else if (value == FEC_4_5)   snprintf(buf, sizeof(buf), "4/5 (H)");
+               else if (value == FEC_5_6)   snprintf(buf, sizeof(buf), "5/6 (H)");
+               else if (value == FEC_6_7)   snprintf(buf, sizeof(buf), "6/7 (H)");
+               else if (value == FEC_7_8)   snprintf(buf, sizeof(buf), "7/8 (H)");
+               else if (value == FEC_8_9)   snprintf(buf, sizeof(buf), "8/9 (H)");
+               else            /*FEC_AUTO*/ snprintf(buf, sizeof(buf), "%s (H)", tr("Auto"));
                value = channel->CoderateL();
-               if      (value == FEC_NONE)  snprintf(buf2, sizeof(buf2), " - %s", tr("None"));
-               else if (value == FEC_1_2)   snprintf(buf2, sizeof(buf2), " - 1/2");
-               else if (value == FEC_2_3)   snprintf(buf2, sizeof(buf2), " - 2/3");
-               else if (value == FEC_3_4)   snprintf(buf2, sizeof(buf2), " - 3/4");
-               else if (value == FEC_4_5)   snprintf(buf2, sizeof(buf2), " - 4/5");
-               else if (value == FEC_5_6)   snprintf(buf2, sizeof(buf2), " - 5/6");
-               else if (value == FEC_6_7)   snprintf(buf2, sizeof(buf2), " - 6/7");
-               else if (value == FEC_7_8)   snprintf(buf2, sizeof(buf2), " - 7/8");
-               else if (value == FEC_8_9)   snprintf(buf2, sizeof(buf2), " - 8/9");
-               else            /*FEC_AUTO*/ snprintf(buf2, sizeof(buf2), " - %s", tr("Auto"));
+               if      (value == FEC_NONE)  snprintf(buf2, sizeof(buf2), " %s (L)", tr("None"));
+               else if (value == FEC_1_2)   snprintf(buf2, sizeof(buf2), " 1/2 (L)");
+               else if (value == FEC_2_3)   snprintf(buf2, sizeof(buf2), " 2/3 (L)");
+               else if (value == FEC_3_4)   snprintf(buf2, sizeof(buf2), " 3/4 (L)");
+               else if (value == FEC_4_5)   snprintf(buf2, sizeof(buf2), " 4/5 (L)");
+               else if (value == FEC_5_6)   snprintf(buf2, sizeof(buf2), " 5/6 (L)");
+               else if (value == FEC_6_7)   snprintf(buf2, sizeof(buf2), " 6/7 (L)");
+               else if (value == FEC_7_8)   snprintf(buf2, sizeof(buf2), " 7/8 (L)");
+               else if (value == FEC_8_9)   snprintf(buf2, sizeof(buf2), " 8/9 (L)");
+               else            /*FEC_AUTO*/ snprintf(buf2, sizeof(buf2), " %s (L)", tr("Auto"));
                strncat(buf, buf2, sizeof(buf));
                m_Osd->DrawText(OSDINFOWIN_X(4), OSDINFOWIN_Y(offset), buf, femonTheme[femonConfig.theme].clrActiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
                offset += OSDROWHEIGHT;
@@ -657,15 +677,19 @@ void cFemonOsd::DrawInfoWindow(void)
                m_Osd->DrawText(OSDINFOWIN_X(4), OSDINFOWIN_Y(offset), buf, femonTheme[femonConfig.theme].clrActiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
                break;
           }
-        m_Osd->DrawEllipse(0, OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDCORNERING, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -3);
-        m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -4);
+        if (IS_OSDCORNERING) {
+           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDCORNERING, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -3);
+           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -4);
+           }
         }
      else if (m_DisplayMode == eFemonModeStream) {
         m_Osd->DrawRectangle(0, OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), femonTheme[femonConfig.theme].clrBackground);
         m_Osd->DrawRectangle(0, OSDINFOWIN_Y(offset), OSDWIDTH, OSDINFOWIN_Y(offset+OSDROWHEIGHT-1), femonTheme[femonConfig.theme].clrTitleBackground);
         m_Osd->DrawText( OSDINFOWIN_X(1), OSDINFOWIN_Y(offset), tr("Stream Information"), femonTheme[femonConfig.theme].clrTitleText, femonTheme[femonConfig.theme].clrTitleBackground, m_Font);
-        m_Osd->DrawEllipse(0, OSDINFOWIN_Y(0), OSDCORNERING, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -2);
-        m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -1);
+        if (IS_OSDCORNERING) {
+           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(0), OSDCORNERING, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -2);
+           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -1);
+           }
         offset += OSDROWHEIGHT;
         m_Osd->DrawText(OSDINFOWIN_X(1), OSDINFOWIN_Y(offset), tr("Video Stream"), femonTheme[femonConfig.theme].clrActiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
         snprintf(buf, sizeof(buf), "#%d", channel->Vpid());
@@ -735,16 +759,20 @@ void cFemonOsd::DrawInfoWindow(void)
            }
         else                         snprintf(buf, sizeof(buf), "---");
         m_Osd->DrawText(OSDINFOWIN_X(3), OSDINFOWIN_Y(offset), buf, femonTheme[femonConfig.theme].clrActiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
-        m_Osd->DrawEllipse(0, OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDCORNERING, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -3);
-        m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -4);
+        if (IS_OSDCORNERING) {
+           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDCORNERING, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -3);
+           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -4);
+           }
         }
      else if (m_DisplayMode == eFemonModeAC3) {
         m_Osd->DrawRectangle(0, OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), femonTheme[femonConfig.theme].clrBackground);
         m_Osd->DrawRectangle(0, OSDINFOWIN_Y(offset), OSDWIDTH, OSDINFOWIN_Y(offset+OSDROWHEIGHT-1), femonTheme[femonConfig.theme].clrTitleBackground);
         snprintf(buf, sizeof(buf), "%s - %s #%d %s", tr("Stream Information"), tr("AC-3 Stream"), IS_DOLBY_TRACK(track) ? channel->Dpid(int(track - ttDolbyFirst)) : channel->Dpid(0), IS_DOLBY_TRACK(track) ? channel->Dlang(int(track - ttDolbyFirst)) : channel->Dlang(0));
         m_Osd->DrawText( OSDINFOWIN_X(1), OSDINFOWIN_Y(offset), buf, femonTheme[femonConfig.theme].clrTitleText, femonTheme[femonConfig.theme].clrTitleBackground, m_Font);
-        m_Osd->DrawEllipse(0, OSDINFOWIN_Y(0), OSDCORNERING, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -2);
-        m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -1);
+        if (IS_OSDCORNERING) {
+           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(0), OSDCORNERING, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -2);
+           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDCORNERING), clrTransparent, -1);
+           }
         offset += OSDROWHEIGHT;
         if (m_Receiver && m_Receiver->AC3Valid() && IS_DOLBY_TRACK(track)) {
            m_Osd->DrawText(OSDINFOWIN_X(1), OSDINFOWIN_Y(offset), tr("Bitrate"), femonTheme[femonConfig.theme].clrInactiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
@@ -830,8 +858,10 @@ void cFemonOsd::DrawInfoWindow(void)
            else           snprintf(buf, sizeof(buf), "---");
            m_Osd->DrawText(OSDINFOWIN_X(3), OSDINFOWIN_Y(offset), buf, femonTheme[femonConfig.theme].clrActiveText, femonTheme[femonConfig.theme].clrBackground, m_Font);
            }
-        m_Osd->DrawEllipse(0, OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDCORNERING, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -3);
-        m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -4);
+        if (IS_OSDCORNERING) {
+           m_Osd->DrawEllipse(0, OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDCORNERING, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -3);
+           m_Osd->DrawEllipse((OSDWIDTH-OSDCORNERING), OSDINFOWIN_Y(OSDINFOHEIGHT-OSDCORNERING), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent, -4);
+           }
         }
      else /* eFemonModeBasic */ {
         m_Osd->DrawRectangle(0, OSDINFOWIN_Y(0), OSDWIDTH, OSDINFOWIN_Y(OSDINFOHEIGHT), clrTransparent);
@@ -844,8 +874,7 @@ void cFemonOsd::Action(void)
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
   cTimeMs t;
-  m_Active = true;
-  while (m_Active) {
+  while (Running()) {
     t.Set(0);
     if (m_Frontend != -1) {
        CHECK(ioctl(m_Frontend, FE_READ_STATUS, &m_FrontendStatus));
@@ -886,13 +915,13 @@ void cFemonOsd::Show(void)
      }
   m_Osd = cOsdProvider::NewOsd(((Setup.OSDWidth - OSDWIDTH) / 2) + Setup.OSDLeft + femonConfig.osdoffset, ((Setup.OSDHeight - OSDHEIGHT) / 2) + Setup.OSDTop);
   if (m_Osd) {
-     tArea Areas1[] = { { 0, 0, OSDWIDTH, OSDHEIGHT, 4 } };
+     tArea Areas1[] = { { 0, 0, OSDWIDTH, OSDHEIGHT, femonTheme[femonConfig.theme].bpp } };
      if (m_Osd->CanHandleAreas(Areas1, sizeof(Areas1) / sizeof(tArea)) == oeOk) {
         m_Osd->SetAreas(Areas1, sizeof(Areas1) / sizeof(tArea));
         }
      else {
-        tArea Areas2[] = { { 0, OSDSTATUSWIN_Y(0),          (OSDWIDTH-1), OSDSTATUSWIN_Y(OSDSTATUSHEIGHT-1), 4 },
-                           { 0, OSDINFOWIN_Y(0),            (OSDWIDTH-1), OSDINFOWIN_Y(OSDROWHEIGHT-1),      4 },
+        tArea Areas2[] = { { 0, OSDSTATUSWIN_Y(0),          (OSDWIDTH-1), OSDSTATUSWIN_Y(OSDSTATUSHEIGHT-1), femonTheme[femonConfig.theme].bpp },
+                           { 0, OSDINFOWIN_Y(0),            (OSDWIDTH-1), OSDINFOWIN_Y(OSDROWHEIGHT-1),      femonTheme[femonConfig.theme].bpp },
                            { 0, OSDINFOWIN_Y(OSDROWHEIGHT), (OSDWIDTH-1), OSDINFOWIN_Y(OSDINFOHEIGHT-1),     2 } };
         m_Osd->SetAreas(Areas2, sizeof(Areas2) / sizeof(tArea));
         }
@@ -963,6 +992,69 @@ void cFemonOsd::SetAudioTrack(int Index, const char * const *Tracks)
      }
 }
 
+bool cFemonOsd::DeviceSwitch(int direction)
+{
+  Dprintf("%s()\n", __PRETTY_FUNCTION__);
+  int device = cDevice::ActualDevice()->DeviceNumber();                            
+  direction = sgn(direction);
+  if (device >= 0) {
+     cChannel *channel = Channels.GetByNumber(cDevice::CurrentChannel());
+     for (int i = 0; i < cDevice::NumDevices() - 1; i++) {                         
+        if (direction) {
+           if (++device >= cDevice::NumDevices()) device = 0;                     
+           }
+        else {
+           if (--device < 0) device = cDevice::NumDevices() - 1;
+           }
+        if (cDevice::GetDevice(device)->ProvidesChannel(channel)) {
+           Dprintf("%s(%d) device(%d)\n", __PRETTY_FUNCTION__, direction, device);
+           // here should be added some checks, if the device is really available (i.e. not recording)
+           cStatus::MsgChannelSwitch(cDevice::PrimaryDevice(), 0);
+           cControl::Shutdown();
+           cDevice::GetDevice(device)->SwitchChannel(channel, true);
+           // does this work with primary devices ?
+           cControl::Launch(new cTransferControl(cDevice::GetDevice(device), channel->Vpid(), channel->Apids(), channel->Dpids(), channel->Spids()));
+           cStatus::MsgChannelSwitch(cDevice::PrimaryDevice(), channel->Number());
+           return (true);
+           }
+        }
+     }
+   return (false);
+}
+
+double cFemonOsd::GetVideoBitrate(void)
+{
+  Dprintf("%s()\n", __PRETTY_FUNCTION__);
+  double value = 0.0;
+
+  if (m_Receiver)
+     value = m_Receiver->VideoBitrate();
+
+  return (value);
+}
+
+double cFemonOsd::GetAudioBitrate(void)
+{
+  Dprintf("%s()\n", __PRETTY_FUNCTION__);
+  double value = 0.0;
+
+  if (m_Receiver)
+     value = m_Receiver->AudioBitrate();
+
+  return (value);
+}
+
+double cFemonOsd::GetDolbyBitrate(void)
+{
+  Dprintf("%s()\n", __PRETTY_FUNCTION__);
+  double value = 0.0;
+
+  if (m_Receiver)
+     value = m_Receiver->AC3Bitrate();
+
+  return (value);
+}
+
 eOSState cFemonOsd::ProcessKey(eKeys Key)
 { 
   eOSState state = cOsdObject::ProcessKey(Key);
@@ -1043,30 +1135,10 @@ eOSState cFemonOsd::ProcessKey(eKeys Key)
                }
             break;
        case kRight:
+            DeviceSwitch(1);
+            break;
        case kLeft:
-            {
-            int device = cDevice::ActualDevice()->DeviceNumber();
-            if (device >= 0) {
-               cChannel *channel = Channels.GetByNumber(cDevice::CurrentChannel());
-               for (int i = 0; i < cDevice::NumDevices() - 1; i++) {
-                   if (NORMALKEY(Key) == kRight) {
-                      if (++device >= cDevice::NumDevices()) device = 0;
-                      }
-                   else {
-                      if (--device < 0) device = cDevice::NumDevices() - 1;
-                      }
-                   if (cDevice::GetDevice(device)->ProvidesChannel(channel)) {
-                      Dprintf("%s(%d) device(%d)\n", __PRETTY_FUNCTION__, Key, device);
-                      cStatus::MsgChannelSwitch(cDevice::PrimaryDevice(), 0);
-                      cControl::Shutdown();
-                      cDevice::GetDevice(device)->SwitchChannel(channel, true);
-                      cControl::Launch(new cTransferControl(cDevice::GetDevice(device), channel->Vpid(), channel->Apids(), channel->Dpids(), channel->Spids()));
-                      cStatus::MsgChannelSwitch(cDevice::PrimaryDevice(), channel->Number());
-                      break;
-                      }
-                   }
-               }
-            }
+            DeviceSwitch(-1);
             break;
        case kUp|k_Repeat:
        case kUp:
