@@ -7,7 +7,7 @@
  */
 
 #include <unistd.h>
-#include <vdr/tools.h>
+#include "femontools.h"
 #include "femoncfg.h"
 #include "femonreceiver.h"
 
@@ -21,7 +21,6 @@ cFemonReceiver::cFemonReceiver(int Ca, int Vpid, int Apid[], int Dpid[])
 :cReceiver(Ca, -1, Vpid, Apid, Dpid, NULL), cThread("femon receiver")
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
-  m_Active = false;
   m_VideoPid = Vpid;
   m_AudioPid = Apid[0];
   m_AC3Pid = Dpid[0];
@@ -59,11 +58,8 @@ cFemonReceiver::cFemonReceiver(int Ca, int Vpid, int Apid[], int Dpid[])
 cFemonReceiver::~cFemonReceiver(void)
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
-  Detach();
-  if (m_Active) {
-     m_Active = false;
-     Cancel();
-     }
+  if (Running())
+     Cancel(3);
 }
 
 /* The following function originates from libdvbmpeg: */
@@ -72,7 +68,7 @@ void cFemonReceiver::GetVideoInfo(uint8_t *mbuf, int count)
   uint8_t *headr;
   int found = 0;
   int c = 0;
-  m_VideoValid = false;
+  //m_VideoValid = false;
   while ((found < 4) && ((c + 4) < count)) {
     uint8_t *b;
     b = mbuf + c;
@@ -165,7 +161,7 @@ void cFemonReceiver::GetAudioInfo(uint8_t *mbuf, int count)
   int found = 0;
   int c = 0;
   int tmp = 0;
-  m_AudioValid = false;
+  //m_AudioValid = false;
   while (!found && (c < count)) {
     uint8_t *b = mbuf + c;
     if ((b[0] == 0xff) && ((b[1] & 0xf8) == 0xf8))
@@ -214,7 +210,7 @@ void cFemonReceiver::GetAC3Info(uint8_t *mbuf, int count)
   int found = 0;
   int c = 0;
   uint8_t frame;
-  m_AC3Valid = false;
+  //m_AC3Valid = false;
   while (!found && (c < count)) {
     uint8_t *b = mbuf + c;
     if ((b[0] == 0x0b) && (b[1] == 0x77))
@@ -253,14 +249,10 @@ void cFemonReceiver::GetAC3Info(uint8_t *mbuf, int count)
 void cFemonReceiver::Activate(bool On)
 {
   Dprintf("%s(%d)\n", __PRETTY_FUNCTION__, On);
-  if (On) {
-     if (!m_Active)
-        Start();
-     }
-  else if (m_Active) {
-     m_Active = false;
+  if (On)
+     Start();
+  else
      Cancel();
-     }
 }
 
 void cFemonReceiver::Receive(uchar *Data, int Length)
@@ -309,8 +301,7 @@ void cFemonReceiver::Action(void)
 {
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
   cTimeMs t;
-  m_Active = true;
-  while (m_Active) {
+  while (Running()) {
         t.Set(0);
         // TS packet 188 bytes - 4 byte header; MPEG standard defines 1Mbit = 1000000bit
         m_VideoBitrate = (8.0 * 184.0 * m_VideoPacketCount) / (femonConfig.calcinterval * 100000.0);
